@@ -1,4 +1,5 @@
 import asyncio
+
 from .version import __version__
 
 
@@ -8,9 +9,9 @@ class ClosedError(Exception):
 
 class _SocketProtocol:
 
-    def __init__(self):
+    def __init__(self, packets_queue_max_size):
         self._error = None
-        self._packets = asyncio.Queue()
+        self._packets = asyncio.Queue(packets_queue_max_size)
 
     def connection_made(self, transport):
         pass
@@ -104,7 +105,7 @@ class Socket:
         self.close()
 
 
-async def create_socket(local_addr=None, remote_addr=None):
+async def create_socket(local_addr=None, remote_addr=None, packets_queue_max_size=0):
     """Create a UDP socket with given local and remote addresses.
 
     >>> sock = await asyncudp.create_socket(local_addr=('127.0.0.1', 9999))
@@ -113,7 +114,7 @@ async def create_socket(local_addr=None, remote_addr=None):
 
     loop = asyncio.get_running_loop()
     transport, protocol = await loop.create_datagram_endpoint(
-        _SocketProtocol,
+        lambda: _SocketProtocol(packets_queue_max_size),
         local_addr=local_addr,
         remote_addr=remote_addr)
 
